@@ -114,36 +114,58 @@ def _process_worker(
                     task_name = task_dict.get("prompt") or f"Task {index}"
 
                     # Use the job_id to group all tasks under the same job
-                    with hud.trace(task_name, job_id=job_id, task_id=task_dict.get("id")):
-                        # Convert dict to Task
-                        task = Task(**task_dict)
+                    with hud.trace(
+                        task_name, job_id=job_id, task_id=task_dict.get("id")
+                    ):
+                        try:
+                            # Convert dict to Task
+                            task = Task(**task_dict)
 
-                        # Create agent instance
-                        agent = agent_class(**(agent_config or {}))
+                            # Create agent instance
+                            agent = agent_class(**(agent_config or {}))
 
-                        if auto_respond:
-                            agent.response_agent = ResponseAgent()
+                            if auto_respond:
+                                agent.response_agent = ResponseAgent()
 
-                        # Run the task
-                        result = await agent.run(task, max_steps=max_steps)
+                            # Run the task - this should ALWAYS return a result, even on error
+                            result = await agent.run(task, max_steps=max_steps)
 
-                        # Extract and print evaluation score for visibility
-                        reward = getattr(result, "reward", "N/A")
-                        logger.info(
-                            "[Worker %s] Task %s: ✓ Completed (reward: %s)",
-                            worker_id,
-                            index,
-                            reward,
-                        )
+                            # Extract and print evaluation score for visibility
+                            reward = getattr(result, "reward", "N/A")
+                            logger.info(
+                                "[Worker %s] Task %s: ✓ Completed (reward: %s)",
+                                worker_id,
+                                index,
+                                reward,
+                            )
 
-                        logger.info(
-                            "[Worker %s] Completed task %s (reward: %s)",
-                            worker_id,
-                            index,
-                            reward,
-                        )
+                            logger.info(
+                                "[Worker %s] Completed task %s (reward: %s)",
+                                worker_id,
+                                index,
+                                reward,
+                            )
 
-                        return (index, result)
+                            return (index, result)
+                        except Exception as e:
+                            # Even if there's an exception, ensure we have a proper result
+                            logger.error(
+                                "[Worker %s] Task %s failed during execution: %s",
+                                worker_id,
+                                index,
+                                str(e)[:200],
+                            )
+                            # Create a proper Trace result for errors
+                            from hud.types import Trace
+
+                            error_result = Trace(
+                                reward=0.0,
+                                done=True,
+                                content=f"Task execution failed: {e}",
+                                isError=True,
+                                info={"error": str(e), "traceback": traceback.format_exc()},
+                            )
+                            return (index, error_result)
 
                 except Exception as e:
                     error_msg = f"Worker {worker_id}: Task {index} failed: {e}"
@@ -190,22 +212,6 @@ def _process_worker(
     try:
         # Run the async batch processing
         results = loop.run_until_complete(process_batch())
-
-        # CRITICAL: Ensure telemetry is fully sent before process exits
-        # Two things need to complete:
-        # 1. The trace context's __exit__ already called _update_task_status_sync (blocking)
-        # 2. But spans are buffered in BatchSpanProcessor and need explicit flush
-
-        from opentelemetry import trace as otel_trace
-
-        provider = otel_trace.get_tracer_provider()
-        if provider and hasattr(provider, "force_flush"):
-            # This forces BatchSpanProcessor to export all buffered spans NOW
-            # The method returns True if successful, False if timeout
-            success = provider.force_flush(timeout_millis=5000)  # 5 second timeout # type: ignore
-            if not success:
-                logger.warning("Worker %s: Telemetry flush timed out", worker_id)
-
         return results
     except KeyboardInterrupt:
         logger.info("Worker %s: Interrupted by user, stopping gracefully", worker_id)
@@ -230,6 +236,25 @@ def _process_worker(
         logger.error("Worker %s batch processing failed: %s", worker_id, e)
         return [(idx, {"error": str(e), "isError": True}) for idx, _ in task_batch]
     finally:
+        # CRITICAL: Always ensure telemetry is fully sent before process exits
+        # This must happen in finally block to ensure it runs even on errors
+        try:
+            from opentelemetry import trace as otel_trace
+
+            provider = otel_trace.get_tracer_provider()
+            if provider and hasattr(provider, "force_flush"):
+                # This forces BatchSpanProcessor to export all buffered spans NOW
+                # The method returns True if successful, False if timeout
+                success = provider.force_flush(
+                    timeout_millis=10000
+                )  # 10 second timeout # type: ignore
+                if not success:
+                    logger.warning("Worker %s: Telemetry flush timed out", worker_id)
+                else:
+                    logger.debug("Worker %s: Telemetry flushed successfully", worker_id)
+        except Exception as flush_error:
+            logger.error("Worker %s: Failed to flush telemetry: %s", worker_id, flush_error)
+
         # Clean up the event loop
         try:
             loop.close()
